# vim: set ts=4 sw=4 et:

# Copyright (c) 2007-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

%if 0%{?suse_version} >= 1120
%bcond_without pulse
%else
%bcond_with    pulse
%endif
%if 0%{?suse_version} > 1140
%bcond_without libcue
%else
%bcond_with    libcue
%endif
%if 0%{?suse_version} > 1110
%bcond_without roar
%else
%bcond_with    roar
%endif

Name:           cmus
Version:        2.7.1
Release:        2.5
Summary:        Curses-based Ogg, MP3, WMA, and WAV Player
Source:         %{name}-%{version}.tar.gz
Source1:        cmus.desktop
Source2:        cmus.png
Patch1:         cmus-rc_ao_default_output_plugin.patch
URL:            http://cmus.sourceforge.net/
Group:          Productivity/Multimedia/Sound/Players
License:        GPL-2.0
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
BuildRequires:  faad2-devel
BuildRequires:  libmp4v2-devel
BuildRequires:  libmpcdec-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig(alsa) >= 1.0.11
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavformat) = 56.40.101
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio_cdda)
%if %{with libcue}
BuildRequires:  pkgconfig(libcue)
%endif
BuildRequires:  pkgconfig(libdiscid)
BuildRequires:  pkgconfig(libmodplug)
%if %{with roar}
BuildRequires:  pkgconfig(libroar)
%endif
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  update-desktop-files
%if %{with pulse}
BuildRequires:  pkgconfig(libpulse) >= 0.9.19
Recommends:     %{name}-plugin-pulse = %{version}-%{release}
%endif #with_pulse
Recommends:     %{name}-plugin-aac = %{version}-%{release}
%if %{with libcue}
Recommends:     %{name}-plugin-cue = %{version}-%{release}
%endif
Recommends:     %{name}-plugin-ffmpeg = %{version}-%{release}
Recommends:     %{name}-plugin-mad = %{version}-%{release}
Recommends:     %{name}-plugin-mp4 = %{version}-%{release}
Recommends:     %{name}-plugin-mpc = %{version}-%{release}
%if %{with roar}
Recommends:     %{name}-plugin-roar = %{version}-%{release}
%endif
Recommends:     %{name}-plugin-wavpack = %{version}-%{release}

%description
CMus is a small and fast text mode music player for Linux and *BSD. Supported
file formats include FLAC, Ogg, MP3 (via libmad), wav, and all module formats
supported by libmodplug. Included output plugins are ALSA, ARTS, OSS, and
Sun. It can be controlled through a UNIX socket. Background playlist loading
and a metadata cache make loading files very fast. Playqueue, playlist filters
and directory browser. Three playlist views are available: artist/album/track,
shuffle list, and sorted list. There are three play modes: all, artist, album.

%if %{with pulse}
%package plugin-pulse
Summary:        Pulseaudio Output Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-pulse
This package proves Pulseaudio output support for the %{name} music player.
It may be removed to avoid unwanted system dependencies on Pulseaudio.
%endif #with_pulse

%package plugin-aac
Summary:        AAC Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-aac
This package proves AAC input support for the %{name} music player.

%package plugin-cdio
Summary:        CDIO plugin for CMus
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-cdio
This package contains plugin for CDIO support.

%if %{with libcue}
%package plugin-cue
Summary:        CUE Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-cue
This package proves CUE input support for the %{name} music player.
%endif

%package plugin-ffmpeg
Summary:        FFmpeg Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-ffmpeg
This package proves ffmpeg input support for the %{name} music player.

%package plugin-mad
Summary:        Mad MP3 Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-mad
This package proves mad (MP3) input support for the %{name} music player.

%package plugin-modplug
Summary:        Modplug Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-modplug
This package proves modplug (mod files) input support for the %{name}
music player.

%package plugin-mp4
Summary:        MP4 Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-mp4
This package proves MP4 input support for the %{name} music player.

%package plugin-mpc
Summary:        MPC (Musepack) Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-mpc
This package proves MPC (Musepack) input support for the %{name} music player.

%package plugin-opus
Summary:        MPC (Musepack) Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-opus
This package proves MPC (Musepack) input support for the %{name} music player.

%if %{with roar}
%package plugin-roar
Summary:        ROAR Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-roar
This package proves ROAR output support for the %{name} music player.
%endif

%package plugin-wavpack
Summary:        Wavpack Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-wavpack
This package proves wavpack input support for the %{name} music player.

%package plugins-all
Summary:        Installs all %{name} plugins
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%if %{with pulse}
Requires:       %{name}-plugin-pulse = %{version}-%{release}
%endif #with_pulse
Requires:       %{name}-plugin-aac = %{version}-%{release}
%if %{with libcue}
Requires:       %{name}-plugin-cue = %{version}-%{release}
%endif
Requires:       %{name}-plugin-ffmpeg = %{version}-%{release}
Requires:       %{name}-plugin-mad = %{version}-%{release}
Requires:       %{name}-plugin-mp4 = %{version}-%{release}
Requires:       %{name}-plugin-mpc = %{version}-%{release}
Requires:       %{name}-plugin-opus = %{version}-%{release}
%if %{with roar}
Requires:       %{name}-plugin-roar = %{version}-%{release}
%endif
Requires:       %{name}-plugin-wavpack = %{version}-%{release}
%description plugins-all
This package pulls in all the plugins for %{name}.


%prep
%setup -q
%patch1

%build
# not autoconf
./configure \
    prefix="%{_prefix}" \
    bindir="%{_bindir}" \
    datadir="%{_datadir}" \
    libdir="%{_libdir}" \
    mandir="%{_mandir}" \
    exampledir="%{_docdir}/%{name}/examples" \
    CONFIG_{ALSA,AO,FLAC,MAD,MODPLUG,MPC,VORBIS,WAV,WAVPACK,MP4,AAC,FFMPEG}=y \
    CONFIG_{ARTS,SUN,WAVEOUT}=n \
    CFLAGS="%{optflags}"

%__make %{?_smp_flags} V=2

%install
%makeinstall

%__mv "%{buildroot}%{_datadir}/cmus/rc.orig" \
      "%{buildroot}%{_datadir}/cmus/rc.dist"

%__install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%__install -D -m0644 "%{SOURCE2}" "%{buildroot}%{_datadir}/pixmaps/cmus.png"
%suse_update_desktop_file -r "%{name}" AudioVideo Player

%__chmod 0644 cmus-status-display

cat<<EOF >README.plugins-all
This subpackage is empty but requires all the available %{name} plugin packages
EOF

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README.md
%doc cmus-status-display
%{_bindir}/cmus
%{_bindir}/cmus-remote
%dir %{_libdir}/cmus
%dir %{_libdir}/cmus/ip
%{_libdir}/cmus/ip/flac.so
%{_libdir}/cmus/ip/vorbis.so
%{_libdir}/cmus/ip/wav.so
%dir %{_libdir}/cmus/op
%{_libdir}/cmus/op/alsa.so
%{_libdir}/cmus/op/ao.so
%{_libdir}/cmus/op/oss.so
%{_libdir}/cmus/op/jack.so
%dir %{_datadir}/cmus
%{_datadir}/cmus/*.theme
%config(noreplace) %{_datadir}/cmus/rc
%{_datadir}/cmus/rc.dist
%doc %{_mandir}/man1/cmus*.1%{ext_man}
%doc %{_mandir}/man7/cmus-tutorial.7%{ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/cmus.png

%if %{with pulse}
%files plugin-pulse
%defattr(-,root,root)
%{_libdir}/cmus/op/pulse.so
%endif #with_pulse

%files plugin-aac
%defattr(-,root,root)
%{_libdir}/cmus/ip/aac.so

%files plugin-cdio
%defattr(-,root,root)
%{_libdir}/cmus/ip/cdio.so

%if %{with libcue}
%files plugin-cue
%defattr(-,root,root)
%{_libdir}/cmus/ip/cue.so
%endif

%files plugin-ffmpeg
%defattr(-,root,root)
%{_libdir}/cmus/ip/ffmpeg.so

%files plugin-mad
%defattr(-,root,root)
%{_libdir}/cmus/ip/mad.so

%files plugin-modplug
%defattr(-,root,root)
%{_libdir}/cmus/ip/modplug.so

%files plugin-mp4
%defattr(-,root,root)
%{_libdir}/cmus/ip/mp4.so

%files plugin-mpc
%defattr(-,root,root)
%{_libdir}/cmus/ip/mpc.so

%files plugin-opus
%defattr(-,root,root)
%{_libdir}/cmus/ip/opus.so

%if %{with roar}
%files plugin-roar
%defattr(-,root,root)
%{_libdir}/cmus/op/roar.so
%endif

%files plugin-wavpack
%defattr(-,root,root)
%{_libdir}/cmus/ip/wavpack.so

%files plugins-all
%defattr(-,root,root)
%doc README.plugins-all

%changelog
* Mon Sep 21 2015 olaf@aepfle.de
- Update t. version 2.7.1
* Mon Sep 21 2015 olaf@aepfle.de
- Convert to BuildRequires pkgconfig, enable libcue,opus,roar support
* Tue Feb 10 2015 avvissu@yandex.ru
- add cdio plugin
* Wed Nov  5 2014 p.seiler@linuxmail.org
- update to version 2.6.0:
  Major new features:
  * show all tracks when artist is selected in the tree view
  * JACK output plugin
  * Opus input plugin
  Other notable new things:
  * «Night» and «Solarized» color schemes
  * reverse sort order support
  * ReplayGain closer to the spec
  * vim-style <c-e> / <c-y> scrolling
  * follow option
  * show_playback_position option
  * XDG directories support
  * better support for newer versions of FFmpeg
  * support for .oga and .ogx file extensions
  * stream metadata in cmus-remote -Q
* Thu Jun 12 2014 p.seiler@linuxmail.org
- Build against ffmpeg(2) not ffmpeg1
- updated package to 2.5.1:
  * CUE sheets support. When adding e.g. `track.flac` to the library, cmus will
  check for `track.cue` or `track.flac.cue` in the same directory. If it founds
  one, it will ignore the tags in `track.flac` and use CUE metadata instead
  * cdio input plugin, for those of you who still remember what a CD is :-)
  * support for WavPack `.wvc` correction files
  * new «zenburn» color scheme (as seen at http://cmus.sf.net/), and text
  attributes (bold/reverse/…) support for UI elements
  * improved tab completion, new `scroll_offset` and `icecast_default_charset`
  options, even better tag parsing and compilations handling, and numerous small
  enhancements all over the place.
* Tue Jan 28 2014 guillaume@opensuse.org
- Build against ffmpeg1 not ffmpeg(2)
* Thu Nov  8 2012 pascal.bleser@opensuse.org
- update to 2.5.0:
  * adds CUE sheet support
  * adds cdio input plugin
  * adds support for WavPack correction files
  * adds a new "zenburn" color scheme
  * improvements to tab completion, tag parsing, and compilation handling
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- update to 2.4.3:
  * maintenance release: it mostly fixes several build and stability issues
    caused by external library changes
* Sun Jul 24 2011 pascal.bleser@opensuse.org
- update to 2.4.2:
  * several important bug and build fixes; everyone is encouraged to upgrade
* Thu May 26 2011 pascal.bleser@opensuse.org
- update to 2.4.1:
  * fixes crashes and misbehaviours
* Sun Apr 24 2011 detlef@links2linux.de
- update to 2.4.0:
  * this release features tons of improvements, with most notable ones being
    live library/playlist filtering and playback resume support
* Sun Apr 10 2011 pascal.bleser@opensuse.org
- update to 2.3.5:
  * several serious (but rarely encountered) issues have been fixed
- build with optflags
* Thu Feb 10 2011 pascal.bleser@opensuse.org
- update to 2.3.4:
  * features an ability to restore the playback volume after restart (when
    using PulseAudio output plugin)
  * adds APE files support (using the FFMPEG input plugin)
  * bugfixes
* Thu Jun 17 2010 pascal@links2linux.de
- update to 2.3.3:
  * a couple of serious bugs has been fixed, so everybody is encouraged to
    upgrade
  * support for the newest version of mp4v2 was added
* Thu Apr 15 2010 pascal@links2linux.de
- update to 2.3.2:
  * libao 1.0 compatibility issue are fixed
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- update to 2.3.1:
  * ID3 parsing was fixed
  * a minor documentation update was done
  * MP3s with broken CRC are now supported
  * a default binding was set for "q"
  * insecure /tmp usage was fixed
* Tue Mar  2 2010 pascal.bleser@opensuse.org
- update to 2.3.0
* Sat Jul 28 2007 guru@unixtech.be
- new package
